package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorDirections;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.MotorHeightSpeed;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.WorkModes;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;

import java.util.TimerTask;

@EqualsAndHashCode(callSuper = true)
@Data
@ToString
public class Brown extends BaseDevMode{

    private Long currentSec = 0l;

    private Thread thread;

    private boolean pasue = false;

    private boolean stop = false;

    private  boolean isMotorType = false;


    public Brown(){

        this.setMode(WorkModes.BROWN);


        //时间
        this.setMinTime(0);
        this.setMaxTime(90 * 60);
        this.setDefaultTime(0);
        this.setTimeChange(true);
        //电机
        this.setDefaultMotorGear(0);
        this.setMinMotorGear(1);
        this.setMaxMotorGear(12);
        this.setMotorDirection(MotorDirections.REVERSE);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(true);

        //温度
        this.setDefaultTemp(0);
        this.setMinTemp(0);
        this.setMaxTemp(130);
        this.setDiyCountDown(true);

    }

    @Override
    public void start() {
        currentSec = 0L;
        this.pasue = false;
        this.setTempChange(false);
        this.setTimeChange(false);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);
        this.setIsStartMotorGear(CofarSDK.devInfo().getMotorGear());
        CofarSDK.startNative();

        this.stop = false;
    }


    @Override
    public void onCountDown(TimerTask timer) {

        if(pasue){
            return;
        }

        DevInfo devInfo = CofarSDK.devInfo();

        /**
         * 在调试试过由于resume的方法，可能没法实时同步转速
         * 在停25的逻辑中在点击暂停的时候设置转速
         * 点击resume按钮回调到resume方法，有可能会导致motorGearBuffer=-1，motorGear=0
         * 估在这写在motorGearBuffer不等于=-1 任何情况下 转速值重新写
         *  后面改了获取getMotorGear ，
         * */
        if (CofarSDK.devInfo().getMotorGear()!=0){
            this.setIsStartMotorGear(devInfo.getMotorGear());
        }


        if (devInfo.getRemainTime() <= 0 && devInfo.getMode().isCountDown()) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }


        if (stop) {
            CofarSDK.stop();
            timer.cancel();
            return;
        }

        devInfo.setRemainTime((short) (devInfo.getRemainTime() - 1));




        if(((currentSec / 5) % 6) == 1){

            if (isMotorType){
                CofarSDK.cfgMotorGearNative((byte)0);
                isMotorType = false;
            }

        }

        if(((currentSec / 5) % 6) == 0){
//            if(MotorDirections.REVERSE == CofarSDK.devInfo().getMotorDirection()){
//                CofarSDK.cfgMotorDirectionNative(MotorDirections.FORWARD);
//            }else{
//                CofarSDK.cfgMotorDirectionNative(MotorDirections.REVERSE);
//            }

            if (!isMotorType){
                CofarSDK.cfgMotorGearNative((byte) getIsStartMotorGear());
                isMotorType = true;
            }
        }


        currentSec++;

    }

    @Override
    public void pause() {
        this.pasue = true;
        CofarSDK.pauseNatvie();
    }

    @Override
    public void resume() {
        this.pasue = false;
        CofarSDK.resumeNavtive();
    }

    @Override
    public void stop() {
        this.stop = true;
        this.setTempChange(true);
        this.setTimeChange(true);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(true);
        CofarSDK.stopNative();
        super.stop();
    }

    @Override
    public void stop(boolean tips) {
        this.stop = true;
        this.setTempChange(true);
        this.setTimeChange(true);
        this.setMotorGearChange(true);
        this.setMotorDirectionChange(true);
        CofarSDK.stopNative();
        super.stop(tips);
    }


}
